@@ -5,8 +5,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 import aws_cdk.aws_codebuild._jsii
 import aws_cdk.aws_codepipeline._jsii
@@ -17,9 +17,9 @@ import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@cloudcomponents/cdk-codepipeline-dockerfile-linter-action",
-    "1.0.24",
+    "1.0.25",
     __name__[0:-6],
-    "cdk-codepipeline-dockerfile-linter-action@1.0.24.jsii.tgz",
+    "cdk-codepipeline-dockerfile-linter-action@1.0.25.jsii.tgz",
 )
 
 __all__ = [
